@@ -392,7 +392,7 @@ def randomStr(dig=6):
     :param dig: 几个字符
     :return:
     """
-    return ''.join(random.choices(string.ascii_lowercase + string.digits, k=k))
+    return ''.join(random.choices(string.ascii_lowercase + string.digits, k=dig))
 
 
 def randomInt(start=0, end=10):
@@ -432,5 +432,59 @@ def compare_func2func(fun1, fun2, test_list=[], times=100, *arg, **kwarg):
 
     return result
 
+
 def substr(s: str, start: int, end: int):
     return s[start: end]
+
+
+def compare_version(v1, v2, cp):
+    """版本比较"""
+
+    def _parse_version(v: str):
+        v = v.strip()
+        # kill_start_alpha
+        while v and not v[0].isdigit():
+            v = v[1:]
+        # replace_spare
+        v = v.replace('-', '.').replace('_', '.').replace(' ', '.')
+        tv = v.split('.')
+        for index, sv in enumerate(tv):
+            if not sv.isdigit() and sv[0].isdigit() and sv[-1].isdigit():
+                a = re.findall('\d+', sv)
+                tv[2] = '.'.join(a)
+        return '.'.join(tv)
+
+    # 1 判断是否包含数字,若有不存在数字
+    if not (bool(re.search(r'\d', v1)) and bool(re.search(r'\d', v2))):
+        if len(v1) == len(v2):
+            return eval('"{}"{}"{}"'.format(v1, cp, v2))
+        else:
+            raise ValueError('{} and {} can\'t compare!'.format(v1, v2))
+
+    v1 = _parse_version(v1)
+    v2 = _parse_version(v2)
+
+    # 3 补齐所有的点
+    d1 = v1.count('.')
+    d2 = v2.count('.')
+    if d1 > d2:
+        v2 += '.0' * (d1 - d2)
+    else:
+        v1 += '.0' * (d2 - d1)
+
+    # 4 计算数字
+    total1 = total2 = step = 0
+    next_step = 1
+    d = v1.count('.')
+    l1 = v1.split('.')
+    l2 = v2.split('.')
+    for i in range(d, -1, -1):
+        tmp1 = int(''.join(filter(str.isdigit, l1[i])) or 0)
+        tmp2 = int(''.join(filter(str.isdigit, l2[i])) or 0)
+        lengh1 = len(str(tmp1))
+        lengh2 = len(str(tmp2))
+        total1 += next_step * tmp1
+        total2 += next_step * tmp2
+        step += max(lengh1, lengh2)
+        next_step = 10 ** step
+    return eval('{} {} {}'.format(total1, cp, total2))
